Changelog for Labware Domain Models
===================================

0.3.1 (2020-12-24)
------------------

- Added calculating well index from rows and columns
- Added calculating well index from well name
